@@ -93,7 +93,7 @@ class pyfile_shell_magic(object):  # assert _pflevel >= 1
         if isinstance(item, slice) or item is ...:
             return self.list(type=type)
         elif isinstance(item, str):
-            return item + _end
+            return [item + _end]
 
         _return = []
         # 第二轮筛选 -- advanced筛选
@@ -159,6 +159,10 @@ class pyfile_shell_magic(object):  # assert _pflevel >= 1
             _return *= self.has(item)
         return bool(_return)
 
+    def __iter__(self):
+        return iter(self.list())
+
+
 class pyfile_shell_basic(pyfile_shell_base, pyfile_shell_basic_magic):
     def __init__(self, path="", type=".inst", aes_type=".aes"):
         pyfile_shell_base.__init__(self, path, type, aes_type, pyfile_basic_files)
